jammy.collections package
=========================

Submodules
----------

jammy.collections.lazy\_dict module
-----------------------------------

.. automodule:: jammy.collections.lazy_dict
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: jammy.collections
   :members:
   :undoc-members:
   :show-inheritance:
